iscsi

package
v0.0.0-...-52cd4e6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 11, 2024 License: Apache-2.0 Imports: 18 Imported by: 0

Documentation

Overview

Package iscsi provide the way to connect/disconnect volume within iSCSI protocol

Package iscsi provide the way to connect/disconnect volume within iSCSI protocol

Package iscsi provide the way to connect/disconnect volume within iSCSI protocol

Package iscsi provide the way to connect/disconnect volume within iSCSI protocol

Package iscsi provide the way to connect/disconnect volume within iSCSI protocol

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type ISCSI

type ISCSI struct {
}

ISCSI implements the Connector interface for ISCSI protocol

func (*ISCSI) ConnectVolume

func (isc *ISCSI) ConnectVolume(ctx context.Context, conn map[string]interface{}) (string, error)

ConnectVolume to mount the source to target path, the source path can be block or nfs Example:

mount /dev/sdb /<target-path>
mount <source-path> /<target-path>

func (*ISCSI) DisConnectVolume

func (isc *ISCSI) DisConnectVolume(ctx context.Context, tgtLunWWN string) error

DisConnectVolume to unmount the target path

Jump to