fake

package
v0.0.0-...-52cd4e6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 11, 2024 License: Apache-2.0 Imports: 10 Imported by: 0

Documentation

Overview

Package fake has the automatically generated clients.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type FakeResourceTopologies

type FakeResourceTopologies struct {
	Fake *FakeXuanwuV1
}

FakeResourceTopologies implements ResourceTopologyInterface

func (*FakeResourceTopologies) Create

func (c *FakeResourceTopologies) Create(ctx context.Context, resourceTopology *xuanwuv1.ResourceTopology, opts v1.CreateOptions) (result *xuanwuv1.ResourceTopology, err error)

Create takes the representation of a resourceTopology and creates it. Returns the server's representation of the resourceTopology, and an error, if there is any.

func (*FakeResourceTopologies) Delete

func (c *FakeResourceTopologies) Delete(ctx context.Context, name string, opts v1.DeleteOptions) error

Delete takes name of the resourceTopology and deletes it. Returns an error if one occurs.

func (*FakeResourceTopologies) DeleteCollection

func (c *FakeResourceTopologies) DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error

DeleteCollection deletes a collection of objects.

func (*FakeResourceTopologies) Get

func (c *FakeResourceTopologies) Get(ctx context.Context, name string, options v1.GetOptions) (result *xuanwuv1.ResourceTopology, err error)

Get takes name of the resourceTopology, and returns the corresponding resourceTopology object, and an error if there is any.

func (*FakeResourceTopologies) List

List takes label and field selectors, and returns the list of ResourceTopologies that match those selectors.

func (*FakeResourceTopologies) Patch

func (c *FakeResourceTopologies) Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *xuanwuv1.ResourceTopology, err error)

Patch applies the patch and returns the patched resourceTopology.

func (*FakeResourceTopologies) Update

func (c *FakeResourceTopologies) Update(ctx context.Context, resourceTopology *xuanwuv1.ResourceTopology, opts v1.UpdateOptions) (result *xuanwuv1.ResourceTopology, err error)

Update takes the representation of a resourceTopology and updates it. Returns the server's representation of the resourceTopology, and an error, if there is any.

func (*FakeResourceTopologies) UpdateStatus

UpdateStatus was generated because the type contains a Status member. Add a +genclient:noStatus comment above the type to avoid generating UpdateStatus().

func (*FakeResourceTopologies) Watch

Watch returns a watch.Interface that watches the requested resourceTopologies.

type FakeStorageBackendClaims

type FakeStorageBackendClaims struct {
	Fake *FakeXuanwuV1
	// contains filtered or unexported fields
}

FakeStorageBackendClaims implements StorageBackendClaimInterface

func (*FakeStorageBackendClaims) Create

func (c *FakeStorageBackendClaims) Create(ctx context.Context, storageBackendClaim *xuanwuv1.StorageBackendClaim, opts v1.CreateOptions) (result *xuanwuv1.StorageBackendClaim, err error)

Create takes the representation of a storageBackendClaim and creates it. Returns the server's representation of the storageBackendClaim, and an error, if there is any.

func (*FakeStorageBackendClaims) Delete

Delete takes name of the storageBackendClaim and deletes it. Returns an error if one occurs.

func (*FakeStorageBackendClaims) DeleteCollection

func (c *FakeStorageBackendClaims) DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error

DeleteCollection deletes a collection of objects.

func (*FakeStorageBackendClaims) Get

func (c *FakeStorageBackendClaims) Get(ctx context.Context, name string, options v1.GetOptions) (result *xuanwuv1.StorageBackendClaim, err error)

Get takes name of the storageBackendClaim, and returns the corresponding storageBackendClaim object, and an error if there is any.

func (*FakeStorageBackendClaims) List

List takes label and field selectors, and returns the list of StorageBackendClaims that match those selectors.

func (*FakeStorageBackendClaims) Patch

func (c *FakeStorageBackendClaims) Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *xuanwuv1.StorageBackendClaim, err error)

Patch applies the patch and returns the patched storageBackendClaim.

func (*FakeStorageBackendClaims) Update

func (c *FakeStorageBackendClaims) Update(ctx context.Context, storageBackendClaim *xuanwuv1.StorageBackendClaim, opts v1.UpdateOptions) (result *xuanwuv1.StorageBackendClaim, err error)

Update takes the representation of a storageBackendClaim and updates it. Returns the server's representation of the storageBackendClaim, and an error, if there is any.

func (*FakeStorageBackendClaims) UpdateStatus

UpdateStatus was generated because the type contains a Status member. Add a +genclient:noStatus comment above the type to avoid generating UpdateStatus().

func (*FakeStorageBackendClaims) Watch

Watch returns a watch.Interface that watches the requested storageBackendClaims.

type FakeStorageBackendContents

type FakeStorageBackendContents struct {
	Fake *FakeXuanwuV1
}

FakeStorageBackendContents implements StorageBackendContentInterface

func (*FakeStorageBackendContents) Create

Create takes the representation of a storageBackendContent and creates it. Returns the server's representation of the storageBackendContent, and an error, if there is any.

func (*FakeStorageBackendContents) Delete

Delete takes name of the storageBackendContent and deletes it. Returns an error if one occurs.

func (*FakeStorageBackendContents) DeleteCollection

func (c *FakeStorageBackendContents) DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error

DeleteCollection deletes a collection of objects.

func (*FakeStorageBackendContents) Get

Get takes name of the storageBackendContent, and returns the corresponding storageBackendContent object, and an error if there is any.

func (*FakeStorageBackendContents) List

List takes label and field selectors, and returns the list of StorageBackendContents that match those selectors.

func (*FakeStorageBackendContents) Patch

func (c *FakeStorageBackendContents) Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *xuanwuv1.StorageBackendContent, err error)

Patch applies the patch and returns the patched storageBackendContent.

func (*FakeStorageBackendContents) Update

Update takes the representation of a storageBackendContent and updates it. Returns the server's representation of the storageBackendContent, and an error, if there is any.

func (*FakeStorageBackendContents) UpdateStatus

UpdateStatus was generated because the type contains a Status member. Add a +genclient:noStatus comment above the type to avoid generating UpdateStatus().

func (*FakeStorageBackendContents) Watch

Watch returns a watch.Interface that watches the requested storageBackendContents.

type FakeVolumeModifyClaims

type FakeVolumeModifyClaims struct {
	Fake *FakeXuanwuV1
}

FakeVolumeModifyClaims implements VolumeModifyClaimInterface

func (*FakeVolumeModifyClaims) Create

func (c *FakeVolumeModifyClaims) Create(ctx context.Context, volumeModifyClaim *xuanwuv1.VolumeModifyClaim, opts v1.CreateOptions) (result *xuanwuv1.VolumeModifyClaim, err error)

Create takes the representation of a volumeModifyClaim and creates it. Returns the server's representation of the volumeModifyClaim, and an error, if there is any.

func (*FakeVolumeModifyClaims) Delete

func (c *FakeVolumeModifyClaims) Delete(ctx context.Context, name string, opts v1.DeleteOptions) error

Delete takes name of the volumeModifyClaim and deletes it. Returns an error if one occurs.

func (*FakeVolumeModifyClaims) DeleteCollection

func (c *FakeVolumeModifyClaims) DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error

DeleteCollection deletes a collection of objects.

func (*FakeVolumeModifyClaims) Get

func (c *FakeVolumeModifyClaims) Get(ctx context.Context, name string, options v1.GetOptions) (result *xuanwuv1.VolumeModifyClaim, err error)

Get takes name of the volumeModifyClaim, and returns the corresponding volumeModifyClaim object, and an error if there is any.

func (*FakeVolumeModifyClaims) List

List takes label and field selectors, and returns the list of VolumeModifyClaims that match those selectors.

func (*FakeVolumeModifyClaims) Patch

func (c *FakeVolumeModifyClaims) Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *xuanwuv1.VolumeModifyClaim, err error)

Patch applies the patch and returns the patched volumeModifyClaim.

func (*FakeVolumeModifyClaims) Update

func (c *FakeVolumeModifyClaims) Update(ctx context.Context, volumeModifyClaim *xuanwuv1.VolumeModifyClaim, opts v1.UpdateOptions) (result *xuanwuv1.VolumeModifyClaim, err error)

Update takes the representation of a volumeModifyClaim and updates it. Returns the server's representation of the volumeModifyClaim, and an error, if there is any.

func (*FakeVolumeModifyClaims) UpdateStatus

UpdateStatus was generated because the type contains a Status member. Add a +genclient:noStatus comment above the type to avoid generating UpdateStatus().

func (*FakeVolumeModifyClaims) Watch

Watch returns a watch.Interface that watches the requested volumeModifyClaims.

type FakeVolumeModifyContents

type FakeVolumeModifyContents struct {
	Fake *FakeXuanwuV1
}

FakeVolumeModifyContents implements VolumeModifyContentInterface

func (*FakeVolumeModifyContents) Create

func (c *FakeVolumeModifyContents) Create(ctx context.Context, volumeModifyContent *xuanwuv1.VolumeModifyContent, opts v1.CreateOptions) (result *xuanwuv1.VolumeModifyContent, err error)

Create takes the representation of a volumeModifyContent and creates it. Returns the server's representation of the volumeModifyContent, and an error, if there is any.

func (*FakeVolumeModifyContents) Delete

Delete takes name of the volumeModifyContent and deletes it. Returns an error if one occurs.

func (*FakeVolumeModifyContents) DeleteCollection

func (c *FakeVolumeModifyContents) DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error

DeleteCollection deletes a collection of objects.

func (*FakeVolumeModifyContents) Get

func (c *FakeVolumeModifyContents) Get(ctx context.Context, name string, options v1.GetOptions) (result *xuanwuv1.VolumeModifyContent, err error)

Get takes name of the volumeModifyContent, and returns the corresponding volumeModifyContent object, and an error if there is any.

func (*FakeVolumeModifyContents) List

List takes label and field selectors, and returns the list of VolumeModifyContents that match those selectors.

func (*FakeVolumeModifyContents) Patch

func (c *FakeVolumeModifyContents) Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *xuanwuv1.VolumeModifyContent, err error)

Patch applies the patch and returns the patched volumeModifyContent.

func (*FakeVolumeModifyContents) Update

func (c *FakeVolumeModifyContents) Update(ctx context.Context, volumeModifyContent *xuanwuv1.VolumeModifyContent, opts v1.UpdateOptions) (result *xuanwuv1.VolumeModifyContent, err error)

Update takes the representation of a volumeModifyContent and updates it. Returns the server's representation of the volumeModifyContent, and an error, if there is any.

func (*FakeVolumeModifyContents) UpdateStatus

UpdateStatus was generated because the type contains a Status member. Add a +genclient:noStatus comment above the type to avoid generating UpdateStatus().

func (*FakeVolumeModifyContents) Watch

Watch returns a watch.Interface that watches the requested volumeModifyContents.

type FakeXuanwuV1

type FakeXuanwuV1 struct {
	*testing.Fake
}

func (*FakeXuanwuV1) RESTClient

func (c *FakeXuanwuV1) RESTClient() rest.Interface

RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.

func (*FakeXuanwuV1) ResourceTopologies

func (c *FakeXuanwuV1) ResourceTopologies() v1.ResourceTopologyInterface

func (*FakeXuanwuV1) StorageBackendClaims

func (c *FakeXuanwuV1) StorageBackendClaims(namespace string) v1.StorageBackendClaimInterface

func (*FakeXuanwuV1) StorageBackendContents

func (c *FakeXuanwuV1) StorageBackendContents() v1.StorageBackendContentInterface

func (*FakeXuanwuV1) VolumeModifyClaims

func (c *FakeXuanwuV1) VolumeModifyClaims() v1.VolumeModifyClaimInterface

func (*FakeXuanwuV1) VolumeModifyContents

func (c *FakeXuanwuV1) VolumeModifyContents() v1.VolumeModifyContentInterface

Jump to