utils

package
v4.6.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 12, 2024 License: Apache-2.0 Imports: 7 Imported by: 0

Documentation

Overview

Package utils provides common utils for connector

Package utils provides common utils for connector

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GetMultiPathInfo

func GetMultiPathInfo(connectionProperties map[string]interface{}) (bool, string, error)

GetMultiPathInfo is used to obtain MultiPath configuration information.

func VerifyMultipathService

func VerifyMultipathService(requiredServices []string, forbiddenServices []string) error

VerifyMultipathService is used to verify the installation and running status of the multipath service.

Types

This section is empty.

Directories

Path Synopsis
Package lock provide Lock and Unlock when manage the disk
Package lock provide Lock and Unlock when manage the disk
Package models provides common models for connector
Package models provides common models for connector

Jump to