Documentation
¶
Overview ¶
Package iscsi provide the way to connect/disconnect volume within iSCSI protocol
Package iscsi provide the way to connect/disconnect volume within iSCSI protocol
Package iscsi provide the way to connect/disconnect volume within iSCSI protocol
Package iscsi provide the way to connect/disconnect volume within iSCSI protocol
Package iscsi provide the way to connect/disconnect volume within iSCSI protocol
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ISCSI ¶
type ISCSI struct {
}
ISCSI implements the Connector interface for ISCSI protocol
func (*ISCSI) ConnectVolume ¶
ConnectVolume to mount the source to target path, the source path can be block or nfs Example:
mount /dev/sdb /<target-path> mount <source-path> /<target-path>
Click to show internal directories.
Click to hide internal directories.