Documentation
¶
Overview ¶
Package fake has the automatically generated clients.
Index ¶
- type FakeResourceTopologies
- func (c *FakeResourceTopologies) Create(ctx context.Context, resourceTopology *xuanwuv1.ResourceTopology, ...) (result *xuanwuv1.ResourceTopology, err error)
- func (c *FakeResourceTopologies) Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
- func (c *FakeResourceTopologies) DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
- func (c *FakeResourceTopologies) Get(ctx context.Context, name string, options v1.GetOptions) (result *xuanwuv1.ResourceTopology, err error)
- func (c *FakeResourceTopologies) List(ctx context.Context, opts v1.ListOptions) (result *xuanwuv1.ResourceTopologyList, err error)
- func (c *FakeResourceTopologies) Patch(ctx context.Context, name string, pt types.PatchType, data []byte, ...) (result *xuanwuv1.ResourceTopology, err error)
- func (c *FakeResourceTopologies) Update(ctx context.Context, resourceTopology *xuanwuv1.ResourceTopology, ...) (result *xuanwuv1.ResourceTopology, err error)
- func (c *FakeResourceTopologies) UpdateStatus(ctx context.Context, resourceTopology *xuanwuv1.ResourceTopology, ...) (*xuanwuv1.ResourceTopology, error)
- func (c *FakeResourceTopologies) Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
- type FakeStorageBackendClaims
- func (c *FakeStorageBackendClaims) Create(ctx context.Context, storageBackendClaim *xuanwuv1.StorageBackendClaim, ...) (result *xuanwuv1.StorageBackendClaim, err error)
- func (c *FakeStorageBackendClaims) Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
- func (c *FakeStorageBackendClaims) DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
- func (c *FakeStorageBackendClaims) Get(ctx context.Context, name string, options v1.GetOptions) (result *xuanwuv1.StorageBackendClaim, err error)
- func (c *FakeStorageBackendClaims) List(ctx context.Context, opts v1.ListOptions) (result *xuanwuv1.StorageBackendClaimList, err error)
- func (c *FakeStorageBackendClaims) Patch(ctx context.Context, name string, pt types.PatchType, data []byte, ...) (result *xuanwuv1.StorageBackendClaim, err error)
- func (c *FakeStorageBackendClaims) Update(ctx context.Context, storageBackendClaim *xuanwuv1.StorageBackendClaim, ...) (result *xuanwuv1.StorageBackendClaim, err error)
- func (c *FakeStorageBackendClaims) UpdateStatus(ctx context.Context, storageBackendClaim *xuanwuv1.StorageBackendClaim, ...) (*xuanwuv1.StorageBackendClaim, error)
- func (c *FakeStorageBackendClaims) Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
- type FakeStorageBackendContents
- func (c *FakeStorageBackendContents) Create(ctx context.Context, storageBackendContent *xuanwuv1.StorageBackendContent, ...) (result *xuanwuv1.StorageBackendContent, err error)
- func (c *FakeStorageBackendContents) Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
- func (c *FakeStorageBackendContents) DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
- func (c *FakeStorageBackendContents) Get(ctx context.Context, name string, options v1.GetOptions) (result *xuanwuv1.StorageBackendContent, err error)
- func (c *FakeStorageBackendContents) List(ctx context.Context, opts v1.ListOptions) (result *xuanwuv1.StorageBackendContentList, err error)
- func (c *FakeStorageBackendContents) Patch(ctx context.Context, name string, pt types.PatchType, data []byte, ...) (result *xuanwuv1.StorageBackendContent, err error)
- func (c *FakeStorageBackendContents) Update(ctx context.Context, storageBackendContent *xuanwuv1.StorageBackendContent, ...) (result *xuanwuv1.StorageBackendContent, err error)
- func (c *FakeStorageBackendContents) UpdateStatus(ctx context.Context, storageBackendContent *xuanwuv1.StorageBackendContent, ...) (*xuanwuv1.StorageBackendContent, error)
- func (c *FakeStorageBackendContents) Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
- type FakeVolumeModifyClaims
- func (c *FakeVolumeModifyClaims) Create(ctx context.Context, volumeModifyClaim *xuanwuv1.VolumeModifyClaim, ...) (result *xuanwuv1.VolumeModifyClaim, err error)
- func (c *FakeVolumeModifyClaims) Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
- func (c *FakeVolumeModifyClaims) DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
- func (c *FakeVolumeModifyClaims) Get(ctx context.Context, name string, options v1.GetOptions) (result *xuanwuv1.VolumeModifyClaim, err error)
- func (c *FakeVolumeModifyClaims) List(ctx context.Context, opts v1.ListOptions) (result *xuanwuv1.VolumeModifyClaimList, err error)
- func (c *FakeVolumeModifyClaims) Patch(ctx context.Context, name string, pt types.PatchType, data []byte, ...) (result *xuanwuv1.VolumeModifyClaim, err error)
- func (c *FakeVolumeModifyClaims) Update(ctx context.Context, volumeModifyClaim *xuanwuv1.VolumeModifyClaim, ...) (result *xuanwuv1.VolumeModifyClaim, err error)
- func (c *FakeVolumeModifyClaims) UpdateStatus(ctx context.Context, volumeModifyClaim *xuanwuv1.VolumeModifyClaim, ...) (*xuanwuv1.VolumeModifyClaim, error)
- func (c *FakeVolumeModifyClaims) Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
- type FakeVolumeModifyContents
- func (c *FakeVolumeModifyContents) Create(ctx context.Context, volumeModifyContent *xuanwuv1.VolumeModifyContent, ...) (result *xuanwuv1.VolumeModifyContent, err error)
- func (c *FakeVolumeModifyContents) Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
- func (c *FakeVolumeModifyContents) DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
- func (c *FakeVolumeModifyContents) Get(ctx context.Context, name string, options v1.GetOptions) (result *xuanwuv1.VolumeModifyContent, err error)
- func (c *FakeVolumeModifyContents) List(ctx context.Context, opts v1.ListOptions) (result *xuanwuv1.VolumeModifyContentList, err error)
- func (c *FakeVolumeModifyContents) Patch(ctx context.Context, name string, pt types.PatchType, data []byte, ...) (result *xuanwuv1.VolumeModifyContent, err error)
- func (c *FakeVolumeModifyContents) Update(ctx context.Context, volumeModifyContent *xuanwuv1.VolumeModifyContent, ...) (result *xuanwuv1.VolumeModifyContent, err error)
- func (c *FakeVolumeModifyContents) UpdateStatus(ctx context.Context, volumeModifyContent *xuanwuv1.VolumeModifyContent, ...) (*xuanwuv1.VolumeModifyContent, error)
- func (c *FakeVolumeModifyContents) Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
- type FakeXuanwuV1
- func (c *FakeXuanwuV1) RESTClient() rest.Interface
- func (c *FakeXuanwuV1) ResourceTopologies() v1.ResourceTopologyInterface
- func (c *FakeXuanwuV1) StorageBackendClaims(namespace string) v1.StorageBackendClaimInterface
- func (c *FakeXuanwuV1) StorageBackendContents() v1.StorageBackendContentInterface
- func (c *FakeXuanwuV1) VolumeModifyClaims() v1.VolumeModifyClaimInterface
- func (c *FakeXuanwuV1) VolumeModifyContents() v1.VolumeModifyContentInterface
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type FakeResourceTopologies ¶
type FakeResourceTopologies struct {
Fake *FakeXuanwuV1
}
FakeResourceTopologies implements ResourceTopologyInterface
func (*FakeResourceTopologies) Create ¶
func (c *FakeResourceTopologies) Create(ctx context.Context, resourceTopology *xuanwuv1.ResourceTopology, opts v1.CreateOptions) (result *xuanwuv1.ResourceTopology, err error)
Create takes the representation of a resourceTopology and creates it. Returns the server's representation of the resourceTopology, and an error, if there is any.
func (*FakeResourceTopologies) Delete ¶
func (c *FakeResourceTopologies) Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
Delete takes name of the resourceTopology and deletes it. Returns an error if one occurs.
func (*FakeResourceTopologies) DeleteCollection ¶
func (c *FakeResourceTopologies) DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
DeleteCollection deletes a collection of objects.
func (*FakeResourceTopologies) Get ¶
func (c *FakeResourceTopologies) Get(ctx context.Context, name string, options v1.GetOptions) (result *xuanwuv1.ResourceTopology, err error)
Get takes name of the resourceTopology, and returns the corresponding resourceTopology object, and an error if there is any.
func (*FakeResourceTopologies) List ¶
func (c *FakeResourceTopologies) List(ctx context.Context, opts v1.ListOptions) (result *xuanwuv1.ResourceTopologyList, err error)
List takes label and field selectors, and returns the list of ResourceTopologies that match those selectors.
func (*FakeResourceTopologies) Patch ¶
func (c *FakeResourceTopologies) Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *xuanwuv1.ResourceTopology, err error)
Patch applies the patch and returns the patched resourceTopology.
func (*FakeResourceTopologies) Update ¶
func (c *FakeResourceTopologies) Update(ctx context.Context, resourceTopology *xuanwuv1.ResourceTopology, opts v1.UpdateOptions) (result *xuanwuv1.ResourceTopology, err error)
Update takes the representation of a resourceTopology and updates it. Returns the server's representation of the resourceTopology, and an error, if there is any.
func (*FakeResourceTopologies) UpdateStatus ¶
func (c *FakeResourceTopologies) UpdateStatus(ctx context.Context, resourceTopology *xuanwuv1.ResourceTopology, opts v1.UpdateOptions) (*xuanwuv1.ResourceTopology, error)
UpdateStatus was generated because the type contains a Status member. Add a +genclient:noStatus comment above the type to avoid generating UpdateStatus().
func (*FakeResourceTopologies) Watch ¶
func (c *FakeResourceTopologies) Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
Watch returns a watch.Interface that watches the requested resourceTopologies.
type FakeStorageBackendClaims ¶
type FakeStorageBackendClaims struct {
Fake *FakeXuanwuV1
// contains filtered or unexported fields
}
FakeStorageBackendClaims implements StorageBackendClaimInterface
func (*FakeStorageBackendClaims) Create ¶
func (c *FakeStorageBackendClaims) Create(ctx context.Context, storageBackendClaim *xuanwuv1.StorageBackendClaim, opts v1.CreateOptions) (result *xuanwuv1.StorageBackendClaim, err error)
Create takes the representation of a storageBackendClaim and creates it. Returns the server's representation of the storageBackendClaim, and an error, if there is any.
func (*FakeStorageBackendClaims) Delete ¶
func (c *FakeStorageBackendClaims) Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
Delete takes name of the storageBackendClaim and deletes it. Returns an error if one occurs.
func (*FakeStorageBackendClaims) DeleteCollection ¶
func (c *FakeStorageBackendClaims) DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
DeleteCollection deletes a collection of objects.
func (*FakeStorageBackendClaims) Get ¶
func (c *FakeStorageBackendClaims) Get(ctx context.Context, name string, options v1.GetOptions) (result *xuanwuv1.StorageBackendClaim, err error)
Get takes name of the storageBackendClaim, and returns the corresponding storageBackendClaim object, and an error if there is any.
func (*FakeStorageBackendClaims) List ¶
func (c *FakeStorageBackendClaims) List(ctx context.Context, opts v1.ListOptions) (result *xuanwuv1.StorageBackendClaimList, err error)
List takes label and field selectors, and returns the list of StorageBackendClaims that match those selectors.
func (*FakeStorageBackendClaims) Patch ¶
func (c *FakeStorageBackendClaims) Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *xuanwuv1.StorageBackendClaim, err error)
Patch applies the patch and returns the patched storageBackendClaim.
func (*FakeStorageBackendClaims) Update ¶
func (c *FakeStorageBackendClaims) Update(ctx context.Context, storageBackendClaim *xuanwuv1.StorageBackendClaim, opts v1.UpdateOptions) (result *xuanwuv1.StorageBackendClaim, err error)
Update takes the representation of a storageBackendClaim and updates it. Returns the server's representation of the storageBackendClaim, and an error, if there is any.
func (*FakeStorageBackendClaims) UpdateStatus ¶
func (c *FakeStorageBackendClaims) UpdateStatus(ctx context.Context, storageBackendClaim *xuanwuv1.StorageBackendClaim, opts v1.UpdateOptions) (*xuanwuv1.StorageBackendClaim, error)
UpdateStatus was generated because the type contains a Status member. Add a +genclient:noStatus comment above the type to avoid generating UpdateStatus().
func (*FakeStorageBackendClaims) Watch ¶
func (c *FakeStorageBackendClaims) Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
Watch returns a watch.Interface that watches the requested storageBackendClaims.
type FakeStorageBackendContents ¶
type FakeStorageBackendContents struct {
Fake *FakeXuanwuV1
}
FakeStorageBackendContents implements StorageBackendContentInterface
func (*FakeStorageBackendContents) Create ¶
func (c *FakeStorageBackendContents) Create(ctx context.Context, storageBackendContent *xuanwuv1.StorageBackendContent, opts v1.CreateOptions) (result *xuanwuv1.StorageBackendContent, err error)
Create takes the representation of a storageBackendContent and creates it. Returns the server's representation of the storageBackendContent, and an error, if there is any.
func (*FakeStorageBackendContents) Delete ¶
func (c *FakeStorageBackendContents) Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
Delete takes name of the storageBackendContent and deletes it. Returns an error if one occurs.
func (*FakeStorageBackendContents) DeleteCollection ¶
func (c *FakeStorageBackendContents) DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
DeleteCollection deletes a collection of objects.
func (*FakeStorageBackendContents) Get ¶
func (c *FakeStorageBackendContents) Get(ctx context.Context, name string, options v1.GetOptions) (result *xuanwuv1.StorageBackendContent, err error)
Get takes name of the storageBackendContent, and returns the corresponding storageBackendContent object, and an error if there is any.
func (*FakeStorageBackendContents) List ¶
func (c *FakeStorageBackendContents) List(ctx context.Context, opts v1.ListOptions) (result *xuanwuv1.StorageBackendContentList, err error)
List takes label and field selectors, and returns the list of StorageBackendContents that match those selectors.
func (*FakeStorageBackendContents) Patch ¶
func (c *FakeStorageBackendContents) Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *xuanwuv1.StorageBackendContent, err error)
Patch applies the patch and returns the patched storageBackendContent.
func (*FakeStorageBackendContents) Update ¶
func (c *FakeStorageBackendContents) Update(ctx context.Context, storageBackendContent *xuanwuv1.StorageBackendContent, opts v1.UpdateOptions) (result *xuanwuv1.StorageBackendContent, err error)
Update takes the representation of a storageBackendContent and updates it. Returns the server's representation of the storageBackendContent, and an error, if there is any.
func (*FakeStorageBackendContents) UpdateStatus ¶
func (c *FakeStorageBackendContents) UpdateStatus(ctx context.Context, storageBackendContent *xuanwuv1.StorageBackendContent, opts v1.UpdateOptions) (*xuanwuv1.StorageBackendContent, error)
UpdateStatus was generated because the type contains a Status member. Add a +genclient:noStatus comment above the type to avoid generating UpdateStatus().
func (*FakeStorageBackendContents) Watch ¶
func (c *FakeStorageBackendContents) Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
Watch returns a watch.Interface that watches the requested storageBackendContents.
type FakeVolumeModifyClaims ¶
type FakeVolumeModifyClaims struct {
Fake *FakeXuanwuV1
}
FakeVolumeModifyClaims implements VolumeModifyClaimInterface
func (*FakeVolumeModifyClaims) Create ¶
func (c *FakeVolumeModifyClaims) Create(ctx context.Context, volumeModifyClaim *xuanwuv1.VolumeModifyClaim, opts v1.CreateOptions) (result *xuanwuv1.VolumeModifyClaim, err error)
Create takes the representation of a volumeModifyClaim and creates it. Returns the server's representation of the volumeModifyClaim, and an error, if there is any.
func (*FakeVolumeModifyClaims) Delete ¶
func (c *FakeVolumeModifyClaims) Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
Delete takes name of the volumeModifyClaim and deletes it. Returns an error if one occurs.
func (*FakeVolumeModifyClaims) DeleteCollection ¶
func (c *FakeVolumeModifyClaims) DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
DeleteCollection deletes a collection of objects.
func (*FakeVolumeModifyClaims) Get ¶
func (c *FakeVolumeModifyClaims) Get(ctx context.Context, name string, options v1.GetOptions) (result *xuanwuv1.VolumeModifyClaim, err error)
Get takes name of the volumeModifyClaim, and returns the corresponding volumeModifyClaim object, and an error if there is any.
func (*FakeVolumeModifyClaims) List ¶
func (c *FakeVolumeModifyClaims) List(ctx context.Context, opts v1.ListOptions) (result *xuanwuv1.VolumeModifyClaimList, err error)
List takes label and field selectors, and returns the list of VolumeModifyClaims that match those selectors.
func (*FakeVolumeModifyClaims) Patch ¶
func (c *FakeVolumeModifyClaims) Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *xuanwuv1.VolumeModifyClaim, err error)
Patch applies the patch and returns the patched volumeModifyClaim.
func (*FakeVolumeModifyClaims) Update ¶
func (c *FakeVolumeModifyClaims) Update(ctx context.Context, volumeModifyClaim *xuanwuv1.VolumeModifyClaim, opts v1.UpdateOptions) (result *xuanwuv1.VolumeModifyClaim, err error)
Update takes the representation of a volumeModifyClaim and updates it. Returns the server's representation of the volumeModifyClaim, and an error, if there is any.
func (*FakeVolumeModifyClaims) UpdateStatus ¶
func (c *FakeVolumeModifyClaims) UpdateStatus(ctx context.Context, volumeModifyClaim *xuanwuv1.VolumeModifyClaim, opts v1.UpdateOptions) (*xuanwuv1.VolumeModifyClaim, error)
UpdateStatus was generated because the type contains a Status member. Add a +genclient:noStatus comment above the type to avoid generating UpdateStatus().
func (*FakeVolumeModifyClaims) Watch ¶
func (c *FakeVolumeModifyClaims) Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
Watch returns a watch.Interface that watches the requested volumeModifyClaims.
type FakeVolumeModifyContents ¶
type FakeVolumeModifyContents struct {
Fake *FakeXuanwuV1
}
FakeVolumeModifyContents implements VolumeModifyContentInterface
func (*FakeVolumeModifyContents) Create ¶
func (c *FakeVolumeModifyContents) Create(ctx context.Context, volumeModifyContent *xuanwuv1.VolumeModifyContent, opts v1.CreateOptions) (result *xuanwuv1.VolumeModifyContent, err error)
Create takes the representation of a volumeModifyContent and creates it. Returns the server's representation of the volumeModifyContent, and an error, if there is any.
func (*FakeVolumeModifyContents) Delete ¶
func (c *FakeVolumeModifyContents) Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
Delete takes name of the volumeModifyContent and deletes it. Returns an error if one occurs.
func (*FakeVolumeModifyContents) DeleteCollection ¶
func (c *FakeVolumeModifyContents) DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
DeleteCollection deletes a collection of objects.
func (*FakeVolumeModifyContents) Get ¶
func (c *FakeVolumeModifyContents) Get(ctx context.Context, name string, options v1.GetOptions) (result *xuanwuv1.VolumeModifyContent, err error)
Get takes name of the volumeModifyContent, and returns the corresponding volumeModifyContent object, and an error if there is any.
func (*FakeVolumeModifyContents) List ¶
func (c *FakeVolumeModifyContents) List(ctx context.Context, opts v1.ListOptions) (result *xuanwuv1.VolumeModifyContentList, err error)
List takes label and field selectors, and returns the list of VolumeModifyContents that match those selectors.
func (*FakeVolumeModifyContents) Patch ¶
func (c *FakeVolumeModifyContents) Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *xuanwuv1.VolumeModifyContent, err error)
Patch applies the patch and returns the patched volumeModifyContent.
func (*FakeVolumeModifyContents) Update ¶
func (c *FakeVolumeModifyContents) Update(ctx context.Context, volumeModifyContent *xuanwuv1.VolumeModifyContent, opts v1.UpdateOptions) (result *xuanwuv1.VolumeModifyContent, err error)
Update takes the representation of a volumeModifyContent and updates it. Returns the server's representation of the volumeModifyContent, and an error, if there is any.
func (*FakeVolumeModifyContents) UpdateStatus ¶
func (c *FakeVolumeModifyContents) UpdateStatus(ctx context.Context, volumeModifyContent *xuanwuv1.VolumeModifyContent, opts v1.UpdateOptions) (*xuanwuv1.VolumeModifyContent, error)
UpdateStatus was generated because the type contains a Status member. Add a +genclient:noStatus comment above the type to avoid generating UpdateStatus().
func (*FakeVolumeModifyContents) Watch ¶
func (c *FakeVolumeModifyContents) Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
Watch returns a watch.Interface that watches the requested volumeModifyContents.
type FakeXuanwuV1 ¶
func (*FakeXuanwuV1) RESTClient ¶
func (c *FakeXuanwuV1) RESTClient() rest.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.
func (*FakeXuanwuV1) ResourceTopologies ¶
func (c *FakeXuanwuV1) ResourceTopologies() v1.ResourceTopologyInterface
func (*FakeXuanwuV1) StorageBackendClaims ¶
func (c *FakeXuanwuV1) StorageBackendClaims(namespace string) v1.StorageBackendClaimInterface
func (*FakeXuanwuV1) StorageBackendContents ¶
func (c *FakeXuanwuV1) StorageBackendContents() v1.StorageBackendContentInterface
func (*FakeXuanwuV1) VolumeModifyClaims ¶
func (c *FakeXuanwuV1) VolumeModifyClaims() v1.VolumeModifyClaimInterface
func (*FakeXuanwuV1) VolumeModifyContents ¶
func (c *FakeXuanwuV1) VolumeModifyContents() v1.VolumeModifyContentInterface