Documentation
¶
Index ¶
- type ResourceTopologyLister
- type ResourceTopologyListerExpansion
- type StorageBackendClaimLister
- type StorageBackendClaimListerExpansion
- type StorageBackendClaimNamespaceLister
- type StorageBackendClaimNamespaceListerExpansion
- type StorageBackendContentLister
- type StorageBackendContentListerExpansion
- type VolumeModifyClaimLister
- type VolumeModifyClaimListerExpansion
- type VolumeModifyContentLister
- type VolumeModifyContentListerExpansion
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ResourceTopologyLister ¶
type ResourceTopologyLister interface {
// List lists all ResourceTopologies in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1.ResourceTopology, err error)
// Get retrieves the ResourceTopology from the index for a given name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1.ResourceTopology, error)
ResourceTopologyListerExpansion
}
ResourceTopologyLister helps list ResourceTopologies. All objects returned here must be treated as read-only.
func NewResourceTopologyLister ¶
func NewResourceTopologyLister(indexer cache.Indexer) ResourceTopologyLister
NewResourceTopologyLister returns a new ResourceTopologyLister.
type ResourceTopologyListerExpansion ¶
type ResourceTopologyListerExpansion interface{}
ResourceTopologyListerExpansion allows custom methods to be added to ResourceTopologyLister.
type StorageBackendClaimLister ¶
type StorageBackendClaimLister interface {
// List lists all StorageBackendClaims in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1.StorageBackendClaim, err error)
// StorageBackendClaims returns an object that can list and get StorageBackendClaims.
StorageBackendClaims(namespace string) StorageBackendClaimNamespaceLister
StorageBackendClaimListerExpansion
}
StorageBackendClaimLister helps list StorageBackendClaims. All objects returned here must be treated as read-only.
func NewStorageBackendClaimLister ¶
func NewStorageBackendClaimLister(indexer cache.Indexer) StorageBackendClaimLister
NewStorageBackendClaimLister returns a new StorageBackendClaimLister.
type StorageBackendClaimListerExpansion ¶
type StorageBackendClaimListerExpansion interface{}
StorageBackendClaimListerExpansion allows custom methods to be added to StorageBackendClaimLister.
type StorageBackendClaimNamespaceLister ¶
type StorageBackendClaimNamespaceLister interface {
// List lists all StorageBackendClaims in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1.StorageBackendClaim, err error)
// Get retrieves the StorageBackendClaim from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1.StorageBackendClaim, error)
StorageBackendClaimNamespaceListerExpansion
}
StorageBackendClaimNamespaceLister helps list and get StorageBackendClaims. All objects returned here must be treated as read-only.
type StorageBackendClaimNamespaceListerExpansion ¶
type StorageBackendClaimNamespaceListerExpansion interface{}
StorageBackendClaimNamespaceListerExpansion allows custom methods to be added to StorageBackendClaimNamespaceLister.
type StorageBackendContentLister ¶
type StorageBackendContentLister interface {
// List lists all StorageBackendContents in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1.StorageBackendContent, err error)
// Get retrieves the StorageBackendContent from the index for a given name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1.StorageBackendContent, error)
StorageBackendContentListerExpansion
}
StorageBackendContentLister helps list StorageBackendContents. All objects returned here must be treated as read-only.
func NewStorageBackendContentLister ¶
func NewStorageBackendContentLister(indexer cache.Indexer) StorageBackendContentLister
NewStorageBackendContentLister returns a new StorageBackendContentLister.
type StorageBackendContentListerExpansion ¶
type StorageBackendContentListerExpansion interface{}
StorageBackendContentListerExpansion allows custom methods to be added to StorageBackendContentLister.
type VolumeModifyClaimLister ¶
type VolumeModifyClaimLister interface {
// List lists all VolumeModifyClaims in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1.VolumeModifyClaim, err error)
// Get retrieves the VolumeModifyClaim from the index for a given name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1.VolumeModifyClaim, error)
VolumeModifyClaimListerExpansion
}
VolumeModifyClaimLister helps list VolumeModifyClaims. All objects returned here must be treated as read-only.
func NewVolumeModifyClaimLister ¶
func NewVolumeModifyClaimLister(indexer cache.Indexer) VolumeModifyClaimLister
NewVolumeModifyClaimLister returns a new VolumeModifyClaimLister.
type VolumeModifyClaimListerExpansion ¶
type VolumeModifyClaimListerExpansion interface{}
VolumeModifyClaimListerExpansion allows custom methods to be added to VolumeModifyClaimLister.
type VolumeModifyContentLister ¶
type VolumeModifyContentLister interface {
// List lists all VolumeModifyContents in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1.VolumeModifyContent, err error)
// Get retrieves the VolumeModifyContent from the index for a given name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1.VolumeModifyContent, error)
VolumeModifyContentListerExpansion
}
VolumeModifyContentLister helps list VolumeModifyContents. All objects returned here must be treated as read-only.
func NewVolumeModifyContentLister ¶
func NewVolumeModifyContentLister(indexer cache.Indexer) VolumeModifyContentLister
NewVolumeModifyContentLister returns a new VolumeModifyContentLister.
type VolumeModifyContentListerExpansion ¶
type VolumeModifyContentListerExpansion interface{}
VolumeModifyContentListerExpansion allows custom methods to be added to VolumeModifyContentLister.